from sentence_transformers import SentenceTransformer
from sklearn.metrics.pairwise import cosine_similarity
import numpy as np
import re


model = SentenceTransformer('all-MiniLM-L6-v2')

SIMILARITY_THRESHOLD = 0.85
stored_texts = []
stored_embeddings = []


def is_similar(new_emb, stored_embs, threshold=SIMILARITY_THRESHOLD):
    return bool(stored_embs and np.max(cosine_similarity([new_emb], stored_embs)) >= threshold)



def get_unique_text(text):
    pieces = [line.strip() for line in re.split(r'\n|(?<=[.!?])\s+', text) if line.strip()]
    unique_pieces = []
    for piece in pieces:
        emb = model.encode(piece)
        if not is_similar(emb, stored_embeddings):
            unique_pieces.append(piece)
            stored_texts.append(piece)
            stored_embeddings.append(emb)
    return " ".join(unique_pieces)






import re
import requests


def minimize_text(content):
    content = re.sub(r'[^\w\s]', '', content)
    content = content.replace("\n", " ")
    return " ".join(content.split())


def clean_and_filter_text(text):
    stopwords = set(
        requests.get(
            "https://gist.githubusercontent.com/rg089/35e00abf8941d72d419224cfd5b5925d/raw/12d899b70156fd0041fa9778d657330b024b959c/stopwords.txt"
        ).text.splitlines()
    )
    filtered_words = [w for w in text.split() if w.lower() not in stopwords]
    return " ".join(filtered_words)
